.. image:: https://img.shields.io/pypi/v/igdiscover.svg?branch=master
    :target: https://pypi.python.org/pypi/igdiscover



==========
IgDiscover
==========

IgDiscover analyzes antibody repertoires and discovers new V genes from high-throughput sequencing reads.
Heavy chains, kappa and lambda light chains are supported (to discover VH, VK and VL genes).

This tool is the result of work within the `Gunilla Karlsson Hedestam group <http://ki.se/en/mtc/gunilla-karlsson-hedestam-group>`_
at the `Department of Microbiology, Tumor and Cell Biology <http://ki.se/en/mtc/>`_ at `Karolinska Institutet <http://ki.se/en/>`_,
Sweden.

IgDiscover was developed at `Science for Life Laboratory (SciLifeLab) <https://www.scilifelab.se/>`_
as a project within the `Bioinformatics Long-Term Support <https://www.scilifelab.se/facilities/wabi/>`_ facility.


Links
-----

* `Documentation <https://igdiscover.readthedocs.io/>`_
* `Source code <https://bitbucket.org/igdiscover/igdiscover/>`_
* `Report an issue <https://bitbucket.org/igdiscover/igdiscover/issues>`_
* `Project page on PyPI (Python package index) <https://pypi.python.org/pypi/igdiscover/>`_
